#! /bin/sh
cd src
../../../../tools/make1mffont ark10 0
../../../../tools/make1mffont ark10 1
../../../../tools/make1mffont dingbat 0
../../../../tools/make1mffont dingbat 1
../../../../tools/make1mffont dingbat 4
cd ..
